==> analitza-16.12.3.tar.xz: analitza-16.12.3/analitza/tests/builtintest.h <==
/*************************************************************************************
 *  Copyright (C) 2011 by Aleix Pol <aleixpol@kde.org>                               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/


#ifndef BUILTINTEST_H
#define BUILTINTEST_H

#include <QtCore/QObject>
#include <analyzer.h>

class BuiltInTest : public QObject
{
    Q_OBJECT
    public:
        BuiltInTest(QObject* parent = 0);
        ~BuiltInTest();
        
    private Q_SLOTS:
        void testCall();
        void testCall_data();
        
    private:
        Analitza::Analyzer a;
};

#endif // BUILTINTEST_H

==> analitza-19.04.2.tar.xz: analitza-19.04.2/analitza/tests/builtintest.h <==
/*************************************************************************************
 *  Copyright (C) 2011 by Aleix Pol <aleixpol@kde.org>                               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/


#ifndef BUILTINTEST_H
#define BUILTINTEST_H

#include <QObject>
#include <analyzer.h>

class BuiltInTest : public QObject
{
    Q_OBJECT
    public:
        BuiltInTest(QObject* parent = nullptr);
        ~BuiltInTest();
        
    private Q_SLOTS:
        void testCall();
        void testCall_data();
        
    private:
        Analitza::Analyzer a;
};

#endif // BUILTINTEST_H
